@@ -29,6 +29,10 @@ class CheckDetails:
 class Commit:
     sha: str
     message: str
+    author_name: str
+    author_email: str
+    committer_name: str
+    committer_email: str
     parents: List[str]
 
 
@@ -61,13 +65,13 @@ class InstallationClient:
 
     def merge(
         self,
-        repository: RepositoryIdentifier,
+        repository: Repository,
         pr_id: int,
         commit_title: Optional[str],
         commit_message: Optional[str],
         method: MergeMethod,
         sha: str,
-    ):
+    ) -> str:
         pass
 
     def add_check(
@@ -91,7 +95,7 @@ class InstallationClient:
 
     def update_pull_request(
         self,
-        repository: RepositoryIdentifier,
+        repository: Repository,
         pr_id: int,
         sha: str,
     ):
